@@ -139,7 +139,7 @@ class MpsClient(AbstractClient):
 
 
     def CreateContentReviewTemplate(self, request):
-        """This API is used to create a custom content audit template. Up to 50 templates can be created.
+        """This API is used to create a custom template for intelligent content recognition. Up to 50 templates can be created.
 
         :param request: Request instance for CreateContentReviewTemplate.
         :type request: :class:`tencentcloud.mps.v20190612.models.CreateContentReviewTemplateRequest`
@@ -195,7 +195,7 @@ class MpsClient(AbstractClient):
 
 
     def CreatePersonSample(self, request):
-        """This API is used to create a figure sample for video processing operations such as content recognition and audit using the face recognition technology.
+        """This API is used to create material samples for video processing operations such as content recognition and detection of inappropriate information with the help of technologies such as facial feature positioning.
 
         :param request: Request instance for CreatePersonSample.
         :type request: :class:`tencentcloud.mps.v20190612.models.CreatePersonSampleRequest`
@@ -335,7 +335,7 @@ class MpsClient(AbstractClient):
 
 
     def CreateWordSamples(self, request):
-        """This API is used to create keyword samples in batches for video processing operations such as content recognition and audit using the OCR and ASR technologies.
+        """This API is used to create keyword samples in batches for video processing operations such as content recognition and detection of inappropriate information with the help of the OCR and ASR technologies.
 
         :param request: Request instance for CreateWordSamples.
         :type request: :class:`tencentcloud.mps.v20190612.models.CreateWordSamplesRequest`
@@ -515,7 +515,7 @@ class MpsClient(AbstractClient):
 
 
     def DeleteContentReviewTemplate(self, request):
-        """This API is used to delete a custom content audit template.
+        """This API is used to delete a custom intelligent content recognition template.
 
         :param request: Request instance for DeleteContentReviewTemplate.
         :type request: :class:`tencentcloud.mps.v20190612.models.DeleteContentReviewTemplateRequest`
@@ -571,7 +571,7 @@ class MpsClient(AbstractClient):
 
 
     def DeletePersonSample(self, request):
-        """This API is used to delete a figure sample based on figure ID.
+        """This API is used to delete the material samples that belong to a material ID.
 
         :param request: Request instance for DeletePersonSample.
         :type request: :class:`tencentcloud.mps.v20190612.models.DeletePersonSampleRequest`
@@ -879,7 +879,7 @@ class MpsClient(AbstractClient):
 
 
     def DescribeContentReviewTemplates(self, request):
-        """This API is used to get the list of content audit templates based on unique template ID. The return result includes all eligible custom and preset content audit templates.
+        """This API is used to get the list of content recognition templates using their unique ID. The returned result includes all custom templates that meet the conditions as well as preset content recognition templates.
 
         :param request: Request instance for DescribeContentReviewTemplates.
         :type request: :class:`tencentcloud.mps.v20190612.models.DescribeContentReviewTemplatesRequest`
@@ -963,7 +963,7 @@ class MpsClient(AbstractClient):
 
 
     def DescribePersonSamples(self, request):
-        """This API is used to query the information of figure samples and supports paged queries by figure ID, name, and tag.
+        """This API is used to query the information of material samples. It supports paginated queries by material ID, name, and tag.
 
         :param request: Request instance for DescribePersonSamples.
         :type request: :class:`tencentcloud.mps.v20190612.models.DescribePersonSamplesRequest`
@@ -1333,8 +1333,7 @@ class MpsClient(AbstractClient):
 
 
     def ManageTask(self, request):
-        """This API is used to manage an initiated task.
-        > Note: currently, you can only terminate an ongoing live stream processing task.
+        """This API is used to manage initiated tasks.
 
         :param request: Request instance for ManageTask.
         :type request: :class:`tencentcloud.mps.v20190612.models.ManageTaskRequest`
@@ -1476,7 +1475,7 @@ class MpsClient(AbstractClient):
 
 
     def ModifyContentReviewTemplate(self, request):
-        """This API is used to modify a custom content audit template.
+        """This API is used to modify a custom intelligent content recognition template.
 
         :param request: Request instance for ModifyContentReviewTemplate.
         :type request: :class:`tencentcloud.mps.v20190612.models.ModifyContentReviewTemplateRequest`
@@ -1532,7 +1531,7 @@ class MpsClient(AbstractClient):
 
 
     def ModifyPersonSample(self, request):
-        """This API is used to modify figure sample information based on figure ID, such as modifying the name and description and adding/deleting/resetting a face or tag. There should be at least one image left after the face deletion operation; otherwise, please use the reset operation.
+        """This API is used to modify material samples by material ID. You can use it to modify the name and description of a material sample and add/delete/reset facial features or tags. There must be at least one image left after the deletion of facial features; otherwise, please reset instead of delete the facial features.
 
         :param request: Request instance for ModifyPersonSample.
         :type request: :class:`tencentcloud.mps.v20190612.models.ModifyPersonSampleRequest`
